.. _inifile:

###################
Configuration files
###################


Introduction
============

The `cosmic-pop` command-line executable cannot run without a configuration file.
Each of the sections below lists inputs for COSMIC's modified version of BSE. Each input has a description of the allowed values and an example of what that section might look like in the INI format; recommended  default settings for many parameters are 
given after their description in boldface.

The buttons below link to the most recent stable and unstable default inifiles for COSMIC.

.. raw:: html

    <div class="toms-nav-container" style="margin-bottom: 3rem; height: 90px; grid-template-rows: 90px">
        <div class="box" data-href="https://github.com/COSMIC-PopSynth/COSMIC/blob/master/examples/Params.ini">Latest stable INIFILE</div>
        <div class="box" data-href="https://github.com/COSMIC-PopSynth/COSMIC/blob/develop/examples/Params.ini">Latest development INIFILE</div>
    </div>



How to use this page
--------------------

**Reference guide** - this page is a great reference for *every* setting available in COSMIC and explains each of the options.

**Interactive config generator** - it can also be used interactively to generate your very own configuration file or BSE settings dictionary for use in running COSMIC.
In each of the following sections you can edit the values of the parameter and the files at the end of the page will update in turn for you to copy. Enjoy configuring COSMIC!

All available settings
======================


Filters
-------

.. raw:: html
    :file: config/config_insert_filters.html


Sampling
--------

.. raw:: html
    :file: config/config_insert_sampling.html


Convergence
-----------

.. raw:: html
    :file: config/config_insert_convergence.html


Random Seed
-----------

.. raw:: html
    :file: config/config_insert_rand_seed.html


Binary physics
--------------

.. raw:: html
    :file: config/config_insert_bse.html


Generated data
==============

The following files are generated by the interactive configuration generator above. They are **updated in real time** as you change the values of the parameters above.

INI file
--------

Use the buttons below to toggle whether to include explanatory comments in the INI file.

.. raw:: html

    <button id="ini-file-comments" type="button" class="btn btn-toggle">Show comments</button>

.. code-block:: ini

    INIFILE HERE

Python BSE settings dictionary
------------------------------

.. code-block:: python

    BSE dictionary HERE

.. this is a dummy line to make sure sphinx imports mathjax
.. math::
    :name: hide-this-maths

    x = y



.. raw:: html

    <script src="../_static/settings.js"></script>
